.. _dev-team:

*****************
zenopy Developers
*****************

``zenopy`` is a free and open-source software that is mainly developed by
Mohammad Mostafanejad at the Molecular Sciences Software Institute (MolSSI).
As it is built for boosting productivity and scientific discovery in all
domains of STEM community and in particular, computational molecular sciences
(CMS), we welcome any feedback and contributions from the members of the
CMS community in both academia and industry.

Lead Maintainers
================

.. Mohammad Mostafanejad

| **Mohammad Mostafanejad** |GH-SinaMostafanejad| |0000-0001-9762-7616|
| Lead Developer
| MolSSI Lead Software Scientist in HPC Education, ML and AI
| Molecular Sciences Software Institute, Blacksburg, VA 24060

.. |GH-SinaMostafanejad| image:: https://cdnjs.cloudflare.com/ajax/libs/octicons/8.5.0/svg/mark-github.svg
   :target: https://github.com/SinaMostafanejad
   :width: 16
   :height: 16
   :alt: GitHub account of SinaMostafanejad

.. |0000-0001-9762-7616| image:: images/orcid.svg
   :target: https://orcid.org/0000-0001-9762-7616
   :width: 16
   :height: 16
   :alt: ORCID profile for https://orcid.org/0000-0001-9762-7616
